@@ -22,6 +22,7 @@
 #include <QDateTime>
 #include <QUuid>
 #include <time.h>
+#include <QTextCodec>
 
 using namespace QtMobility;
 
@@ -40,9 +41,13 @@ SmsSender::SmsSender(int argc, char *argv[]) :
     //This is not possible with a CLI program (should exit as the sms is sent).
     //m_DeliveryReport = false;
     m_Validity = 167;
-    m_Argc = argc - 1;
-    for (int i=1; i<argc; i++)
+    m_Argc = argc - 1;                
+
+    m_Argv = QCoreApplication::arguments();
+    m_Argv.removeFirst();
+    /*for (int i=1; i<argc; i++){
         m_Argv.append(argv[i]);
+    }*/
 }
 
 SmsSender::~SmsSender()
